# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "PagedBudgetList",
    "Item",
    "ItemTotals",
    "ItemTotalsCost",
    "ItemTotalsCostInputCost",
    "ItemTotalsCostOutputCost",
    "ItemTotalsCostTotalCost",
    "ItemTotalsRequests",
]


class ItemTotalsCostInputCost(BaseModel):
    base: Optional[float] = None

    overrun_base: Optional[float] = None


class ItemTotalsCostOutputCost(BaseModel):
    base: Optional[float] = None

    overrun_base: Optional[float] = None


class ItemTotalsCostTotalCost(BaseModel):
    base: Optional[float] = None

    overrun_base: Optional[float] = None


class ItemTotalsCost(BaseModel):
    input_cost: Optional[ItemTotalsCostInputCost] = FieldInfo(alias="inputCost", default=None)

    output_cost: Optional[ItemTotalsCostOutputCost] = FieldInfo(alias="outputCost", default=None)

    total_cost: Optional[ItemTotalsCostTotalCost] = FieldInfo(alias="totalCost", default=None)


class ItemTotalsRequests(BaseModel):
    blocked: Optional[int] = None

    error: Optional[int] = None

    exceeded: Optional[int] = None

    failed: Optional[int] = None

    successful: Optional[int] = None

    total: Optional[int] = None


class ItemTotals(BaseModel):
    cost: Optional[ItemTotalsCost] = None

    requests: Optional[ItemTotalsRequests] = None


class Item(BaseModel):
    base_cost_estimate: Literal["Max"]

    budget_creation_timestamp: datetime

    budget_id: str

    budget_name: str

    budget_response_type: Literal["Block", "Allow"]

    budget_type: Literal["Conservative", "Liberal"]

    budget_update_timestamp: datetime

    currency: str

    max: float

    totals: ItemTotals

    budget_tags: Optional[List[str]] = None


class PagedBudgetList(BaseModel):
    current_page: Optional[int] = FieldInfo(alias="currentPage", default=None)

    has_next_page: Optional[bool] = FieldInfo(alias="hasNextPage", default=None)

    has_previous_page: Optional[bool] = FieldInfo(alias="hasPreviousPage", default=None)

    items: Optional[List[Item]] = None

    message: Optional[str] = None

    page_size: Optional[int] = FieldInfo(alias="pageSize", default=None)

    request_id: Optional[str] = None

    total_count: Optional[int] = FieldInfo(alias="totalCount", default=None)

    total_pages: Optional[int] = FieldInfo(alias="totalPages", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from .._models import BaseModel

__all__ = ["SuccessfulProxyResult", "Budgets", "Cost", "CostInput", "CostOutput", "CostTotal"]


class Budgets(BaseModel):
    state: Optional[str] = None


class CostInput(BaseModel):
    base: Optional[float] = None


class CostOutput(BaseModel):
    base: Optional[float] = None


class CostTotal(BaseModel):
    base: Optional[float] = None


class Cost(BaseModel):
    currency: Optional[str] = None

    input: Optional[CostInput] = None

    output: Optional[CostOutput] = None

    total: Optional[CostTotal] = None


class SuccessfulProxyResult(BaseModel):
    budgets: Optional[Dict[str, Budgets]] = None

    cost: Optional[Cost] = None

    request_id: Optional[str] = None

    request_tags: Optional[List[str]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["BudgetUpdateParams"]


class BudgetUpdateParams(TypedDict, total=False):
    budget_name: Required[str]

    max: float



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["IngestUnitsParams", "Units"]


class IngestUnitsParams(TypedDict, total=False):
    category: Required[str]

    resource: Required[str]

    units: Required[Units]

    x_proxy_budget_ids: Annotated[str, PropertyInfo(alias="xProxy-Budget-IDs")]

    x_proxy_request_tags: Annotated[str, PropertyInfo(alias="xProxy-Request-Tags")]


class Units(TypedDict, total=False):
    input: int

    output: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "BudgetResponse",
    "Budget",
    "BudgetTotals",
    "BudgetTotalsCost",
    "BudgetTotalsCostInputCost",
    "BudgetTotalsCostOutputCost",
    "BudgetTotalsCostTotalCost",
    "BudgetTotalsRequests",
]


class BudgetTotalsCostInputCost(BaseModel):
    base: Optional[float] = None

    overrun_base: Optional[float] = None


class BudgetTotalsCostOutputCost(BaseModel):
    base: Optional[float] = None

    overrun_base: Optional[float] = None


class BudgetTotalsCostTotalCost(BaseModel):
    base: Optional[float] = None

    overrun_base: Optional[float] = None


class BudgetTotalsCost(BaseModel):
    input_cost: Optional[BudgetTotalsCostInputCost] = FieldInfo(alias="inputCost", default=None)

    output_cost: Optional[BudgetTotalsCostOutputCost] = FieldInfo(alias="outputCost", default=None)

    total_cost: Optional[BudgetTotalsCostTotalCost] = FieldInfo(alias="totalCost", default=None)


class BudgetTotalsRequests(BaseModel):
    blocked: Optional[int] = None

    error: Optional[int] = None

    exceeded: Optional[int] = None

    failed: Optional[int] = None

    successful: Optional[int] = None

    total: Optional[int] = None


class BudgetTotals(BaseModel):
    cost: Optional[BudgetTotalsCost] = None

    requests: Optional[BudgetTotalsRequests] = None


class Budget(BaseModel):
    base_cost_estimate: Literal["Max"]

    budget_creation_timestamp: datetime

    budget_id: str

    budget_name: str

    budget_response_type: Literal["Block", "Allow"]

    budget_type: Literal["Conservative", "Liberal"]

    budget_update_timestamp: datetime

    currency: str

    max: float

    totals: BudgetTotals

    budget_tags: Optional[List[str]] = None


class BudgetResponse(BaseModel):
    budget: Budget

    request_id: str

    message: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["BudgetTagsResponse"]


class BudgetTagsResponse(BaseModel):
    created_on: Optional[datetime] = FieldInfo(alias="createdOn", default=None)

    tag_id: Optional[int] = FieldInfo(alias="tagId", default=None)

    tag_name: Optional[str] = FieldInfo(alias="tagName", default=None)
